@@ -1,4 +1,4 @@
-/* $Id: contact.c,v 1.12 2009/05/29 04:50:58 judd Exp $ */
+/* $Id: contact.c,v 1.23 2010-04-01 23:09:59 rikster5 Exp $ */
 
 /*******************************************************************************
  * contact.c
@@ -52,48 +52,48 @@ static int glob_sort_rule;
 /* Used for mapping between Contacts and Addresses */
 static long cont_addr_map[CONT_ADDR_MAP_SIZE]={
    contLastname, entryLastname,
-     contFirstname, entryFirstname,
-     contCompany, entryCompany,
-     contTitle, entryTitle,
-     contPhone1, entryPhone1,
-     contPhone2, entryPhone2,
-     contPhone3, entryPhone3,
-     contPhone4, entryPhone4,
-     contPhone5, entryPhone5,
-     contPhone6, -1,
-     contPhone7, -1,
-     contIM1, -1,
-     contIM2, -1,
-     contWebsite, -1,
-     contCustom1, entryCustom1,
-     contCustom2, entryCustom2,
-     contCustom3, entryCustom3,
-     contCustom4, entryCustom4,
-     contCustom5, -1,
-     contCustom6, -1,
-     contCustom7, -1,
-     contCustom8, -1,
-     contCustom9, -1,
-     contAddress1, entryAddress,
-     contCity1, entryCity,
-     contState1, entryState,
-     contZip1, entryZip,
-     contCountry1, entryCountry,
-     contAddress2, -1,
-     contCity2, -1,
-     contState2, -1,
-     contZip2, -1,
-     contCountry2, -1,
-     contAddress3, -1,
-     contCity3, -1,
-     contState3, -1,
-     contZip3, -1,
-     contCountry3, -1,
-     contNote, entryNote
+   contFirstname, entryFirstname,
+   contCompany, entryCompany,
+   contTitle, entryTitle,
+   contPhone1, entryPhone1,
+   contPhone2, entryPhone2,
+   contPhone3, entryPhone3,
+   contPhone4, entryPhone4,
+   contPhone5, entryPhone5,
+   contPhone6, -1,
+   contPhone7, -1,
+   contIM1, -1,
+   contIM2, -1,
+   contWebsite, -1,
+   contCustom1, entryCustom1,
+   contCustom2, entryCustom2,
+   contCustom3, entryCustom3,
+   contCustom4, entryCustom4,
+   contCustom5, -1,
+   contCustom6, -1,
+   contCustom7, -1,
+   contCustom8, -1,
+   contCustom9, -1,
+   contAddress1, entryAddress,
+   contCity1, entryCity,
+   contState1, entryState,
+   contZip1, entryZip,
+   contCountry1, entryCountry,
+   contAddress2, -1,
+   contCity2, -1,
+   contState2, -1,
+   contZip2, -1,
+   contCountry2, -1,
+   contAddress3, -1,
+   contCity3, -1,
+   contState3, -1,
+   contZip3, -1,
+   contCountry3, -1,
+   contNote, entryNote
 };
 
 /****************************** Main Code *************************************/
-int contact_compare(const void *v1, const void *v2)
+static int contact_compare(const void *v1, const void *v2)
 {
    ContactList **cl1, **cl2;
    struct Contact *c1, *c2;
@@ -129,9 +129,9 @@ int contact_compare(const void *v1, const void *v2)
 
    last_cmp1=last_cmp2=0;
 
-   if (!(glob_sort_rule & SORT_JAPANESE) | (glob_sort_rule & SORT_JOS)) { /* normal */
+   if (!(glob_sort_rule & SORT_JAPANESE) || (glob_sort_rule & SORT_JOS)) { /* normal */
       while (last_cmp1 < 3 && last_cmp2 < 3) {
-	 str1=str2=NULL;
+         str1=str2=NULL;
          /* Find the next non-blank field to use for sorting */
          for (i=last_cmp1+1; i<=3; i++) {
             if (c1->entry[sort_idx[i]]) {
@@ -197,72 +197,72 @@ int contact_compare(const void *v1, const void *v2)
       sort3 = sort_idx[3];
 
       if (c1->entry[sort1] || c1->entry[sort2]) {
-	 if (c1->entry[sort1] && c1->entry[sort2]) {
-	    if (!(tmp_p1 = strchr(c1->entry[sort1],'\1'))) tmp_p1=c1->entry[sort1]+1;
-	    if (!(tmp_p2 = strchr(c1->entry[sort2],'\1'))) tmp_p2=c1->entry[sort2]+1;
-	    if ((str1 = malloc(strlen(tmp_p1)+strlen(tmp_p2)+1)) == NULL) {
-	       return 0;
-	    }
-	    strcpy(str1, tmp_p1);
-	    strcat(str1, tmp_p2);
-	 }
-	 if (c1->entry[sort1] && (!c1->entry[sort2])) {
-	    if (!(tmp_p1 = strchr(c1->entry[sort1],'\1'))) tmp_p1=c1->entry[sort1]+1;
-	    if ((str1 = malloc(strlen(tmp_p1)+1)) == NULL) {
-	       return 0;
-	    }
-	    strcpy(str1, tmp_p1);
-	 }
-	 if ((!c1->entry[sort1]) && c1->entry[sort2]) {
-	    if (!(tmp_p2 = strchr(c1->entry[sort2],'\1'))) tmp_p2=c1->entry[sort2]+1;
-	    if ((str1 = malloc(strlen(tmp_p2)+1)) == NULL) {
-	       return 0;
-	    }
-	    strcpy(str1, tmp_p2);
-	 }
+         if (c1->entry[sort1] && c1->entry[sort2]) {
+            if (!(tmp_p1 = strchr(c1->entry[sort1],'\1'))) tmp_p1=c1->entry[sort1]+1;
+            if (!(tmp_p2 = strchr(c1->entry[sort2],'\1'))) tmp_p2=c1->entry[sort2]+1;
+            if ((str1 = malloc(strlen(tmp_p1)+strlen(tmp_p2)+1)) == NULL) {
+               return 0;
+            }
+            strcpy(str1, tmp_p1);
+            strcat(str1, tmp_p2);
+         }
+         if (c1->entry[sort1] && (!c1->entry[sort2])) {
+            if (!(tmp_p1 = strchr(c1->entry[sort1],'\1'))) tmp_p1=c1->entry[sort1]+1;
+            if ((str1 = malloc(strlen(tmp_p1)+1)) == NULL) {
+               return 0;
+            }
+            strcpy(str1, tmp_p1);
+         }
+         if ((!c1->entry[sort1]) && c1->entry[sort2]) {
+            if (!(tmp_p2 = strchr(c1->entry[sort2],'\1'))) tmp_p2=c1->entry[sort2]+1;
+            if ((str1 = malloc(strlen(tmp_p2)+1)) == NULL) {
+               return 0;
+            }
+            strcpy(str1, tmp_p2);
+         }
       } else if (c1->entry[sort3]) {
-	 if (!(tmp_p3 = strchr(c1->entry[sort3],'\1'))) tmp_p3=c1->entry[sort3]+1;
-	 if ((str1 = malloc(strlen(tmp_p3)+1)) == NULL) {
-	    return 0;
-	 }
-	 strcpy(str1, tmp_p3);
+         if (!(tmp_p3 = strchr(c1->entry[sort3],'\1'))) tmp_p3=c1->entry[sort3]+1;
+         if ((str1 = malloc(strlen(tmp_p3)+1)) == NULL) {
+            return 0;
+         }
+         strcpy(str1, tmp_p3);
       } else {
-	 return 1;
+         return 1;
       }
 
       if (c2->entry[sort1] || c2->entry[sort2]) {
-	 if (c2->entry[sort1] && c2->entry[sort2]) {
-	    if (!(tmp_p1 = strchr(c2->entry[sort1],'\1'))) tmp_p1=c2->entry[sort1]+1;
-	    if (!(tmp_p2 = strchr(c2->entry[sort2],'\1'))) tmp_p2=c2->entry[sort2]+1;
-	    if ((str2 = malloc(strlen(tmp_p1)+strlen(tmp_p2)+1)) == NULL) {
-	       return 0;
-	    }
-	    strcpy(str2, tmp_p1);
-	    strcat(str2, tmp_p2);
-	 }
-	 if (c2->entry[sort1] && (!c2->entry[sort2])) {
-	    if (!(tmp_p1 = strchr(c2->entry[sort1],'\1'))) tmp_p1=c2->entry[sort1]+1;
-	    if ((str2 = malloc(strlen(tmp_p1)+1)) == NULL) {
-	       return 0;
-	    }
-	    strcpy(str2, tmp_p1);
-	 }
-	 if ((!c2->entry[sort1]) && c2->entry[sort2]) {
-	    if (!(tmp_p2 = strchr(c2->entry[sort2],'\1'))) tmp_p2=c2->entry[sort2]+1;
-	    if ((str2 = malloc(strlen(tmp_p2)+1)) == NULL) {
-	       return 0;
-	    }
-	    strcpy(str2, tmp_p2);
-	 }
+         if (c2->entry[sort1] && c2->entry[sort2]) {
+            if (!(tmp_p1 = strchr(c2->entry[sort1],'\1'))) tmp_p1=c2->entry[sort1]+1;
+            if (!(tmp_p2 = strchr(c2->entry[sort2],'\1'))) tmp_p2=c2->entry[sort2]+1;
+            if ((str2 = malloc(strlen(tmp_p1)+strlen(tmp_p2)+1)) == NULL) {
+               return 0;
+            }
+            strcpy(str2, tmp_p1);
+            strcat(str2, tmp_p2);
+         }
+         if (c2->entry[sort1] && (!c2->entry[sort2])) {
+            if (!(tmp_p1 = strchr(c2->entry[sort1],'\1'))) tmp_p1=c2->entry[sort1]+1;
+            if ((str2 = malloc(strlen(tmp_p1)+1)) == NULL) {
+               return 0;
+            }
+            strcpy(str2, tmp_p1);
+         }
+         if ((!c2->entry[sort1]) && c2->entry[sort2]) {
+            if (!(tmp_p2 = strchr(c2->entry[sort2],'\1'))) tmp_p2=c2->entry[sort2]+1;
+            if ((str2 = malloc(strlen(tmp_p2)+1)) == NULL) {
+               return 0;
+            }
+            strcpy(str2, tmp_p2);
+         }
       } else if (c2->entry[sort3]) {
-	 if (!(tmp_p3 = strchr(c2->entry[sort3],'\1'))) tmp_p3=c2->entry[sort3]+1;
-	 if ((str2 = malloc(strlen(tmp_p3)+1)) == NULL) {
-	    return 0;
-	 }
-	 strcpy(str2, tmp_p3);
+         if (!(tmp_p3 = strchr(c2->entry[sort3],'\1'))) tmp_p3=c2->entry[sort3]+1;
+         if ((str2 = malloc(strlen(tmp_p3)+1)) == NULL) {
+            return 0;
+         }
+         strcpy(str2, tmp_p3);
       } else {
-	 free(str1);
-	 return -1;
+         free(str1);
+         return -1;
       }
 
       /* lower case the strings for a better compare */
@@ -286,9 +286,9 @@ int contact_compare(const void *v1, const void *v2)
 }
 
 /*
- * sort_order: 0=descending,  1=ascending
+ * sort_order: SORT_ASCENDING | SORT_DESCENDING
  */
-int contacts_sort(ContactList **cl, int sort_order)
+static int contacts_sort(ContactList **cl, int sort_order)
 {
    ContactList *temp_cl;
    ContactList **sort_cl;
@@ -337,13 +337,13 @@ int contacts_sort(ContactList **cl, int sort_order)
    if (sort_order==SORT_ASCENDING) {
       sort_cl[count-1]->next = NULL;
       for (i=count-1; i>0; i--) {
-	 sort_cl[i-1]->next=sort_cl[i];
+         sort_cl[i-1]->next=sort_cl[i];
       }
       *cl = sort_cl[0];
    } else {
       /* Descending order */
       for (i=count-1; i>0; i--) {
-	 sort_cl[i]->next=sort_cl[i-1];
+         sort_cl[i]->next=sort_cl[i-1];
       }
       sort_cl[0]->next = NULL;
       *cl = sort_cl[count-1];
@@ -361,42 +361,30 @@ int copy_address_ai_to_contact_ai(const struct AddressAppInfo *aai, struct Conta
 
    memcpy(&cai->category, &aai->category, sizeof(struct CategoryAppInfo));
 
-#ifdef PILOT_LINK_GT_0_12_4
    memset(&cai->internal, '\0', 26);
-#else
-   memset(&cai->unknown1, '\0', 26);
-#endif
 
    for (i=0; i<NUM_CONTACT_ENTRIES; i++) {
       c_entry = cont_addr_map[i*2];
       a_entry = cont_addr_map[i*2+1];
       if ((c_entry>=0) && (a_entry>=0)) {
-	 strncpy(cai->labels[c_entry], aai->labels[a_entry], 16);
-	 cai->labels[c_entry][15]='\0';
+         strncpy(cai->labels[c_entry], aai->labels[a_entry], 16);
+         cai->labels[c_entry][15]='\0';
       } else {
-	 if (c_entry>=0) {
-	    cai->labels[c_entry][0]='\0';
-	 }
+         if (c_entry>=0) {
+            cai->labels[c_entry][0]='\0';
+         }
       }
    }
 
    /* The rest of the labels do not exist in address */
-#ifdef PILOT_LINK_GT_0_12_4
    if (cai->type==contacts_v10) {
-#else
-   if (cai->version==10) {
-#endif
       for (i=NUM_CONTACT_ENTRIES; i<NUM_CONTACT_V10_LABELS; i++) {
-	 cai->labels[i][0]='\0';
+         cai->labels[i][0]='\0';
       }
    }
-#ifdef PILOT_LINK_GT_0_12_4
    if (cai->type==contacts_v11) {
-#else
-   if (cai->version==11) {
-#endif
       for (i=NUM_CONTACT_ENTRIES; i<NUM_CONTACT_V11_LABELS; i++) {
-	 cai->labels[i][0]='\0';
+         cai->labels[i][0]='\0';
       }
    }
 
@@ -414,10 +402,9 @@ int copy_address_ai_to_contact_ai(const struct AddressAppInfo *aai, struct Conta
    for (i=0; i<5; i++) {
       cai->IMLabels[i][0] = '\0';
    }
-   return 0;
+   return EXIT_SUCCESS;
 }
 
-/* Copy AppInfo data structures */
 int copy_address_to_contact(const struct Address *a, struct Contact *c)
 {
    int i, a_entry, c_entry;
@@ -428,9 +415,9 @@ int copy_address_to_contact(const struct Address *a, struct Contact *c)
       
       c->entry[c_entry]=NULL;
       if ((c_entry>=0) && (a_entry>=0)) {
-	 if (a->entry[a_entry]) {
-	    c->entry[c_entry]=strdup(a->entry[a_entry]);
-	 }
+         if (a->entry[a_entry]) {
+            c->entry[c_entry]=strdup(a->entry[a_entry]);
+         }
       }
    }
 
@@ -455,14 +442,14 @@ int copy_address_to_contact(const struct Address *a, struct Contact *c)
 
    c->reminder = 0;
    c->advance = 0;
-   c->advanceUnits = 0;	   
+   c->advanceUnits = 0;    
    memset(&(c->birthday), 0, sizeof(struct tm));
    for (i=0; i<MAX_CONTACT_BLOBS; i++) {
       c->blob[i] = NULL;
    }
    c->picture = NULL;
 
-   return 0;
+   return EXIT_SUCCESS;
 }
 
 int copy_addresses_to_contacts(AddressList *al, ContactList **cl)
@@ -482,16 +469,20 @@ int copy_addresses_to_contacts(AddressList *al, ContactList **cl)
       temp_cl->app_type = CONTACTS;
       temp_cl->next=NULL;
       if (!last_cl) {
-	 *cl = last_cl = temp_cl;
+         *cl = last_cl = temp_cl;
       } else {
-	 last_cl->next = temp_cl;
-	 last_cl = temp_cl;
+         last_cl->next = temp_cl;
+         last_cl = temp_cl;
       }
    }
-   return 0;
+
+   return EXIT_SUCCESS;
 }
 
-int copy_contact_ai_to_address_ai(const struct ContactAppInfo *cai, struct AddressAppInfo *aai)
+/* Unused at this time: 2010/03/31 */
+/*
+static int copy_contact_ai_to_address_ai(const struct ContactAppInfo *cai, 
+                                         struct AddressAppInfo *aai)
 {
    int i, a_entry, c_entry;
 
@@ -501,12 +492,12 @@ int copy_contact_ai_to_address_ai(const struct ContactAppInfo *cai, struct Addre
       c_entry = cont_addr_map[i*2];
       a_entry = cont_addr_map[i*2+1];
       if ((c_entry>=0) && (a_entry>=0)) {
-	 strncpy(aai->labels[a_entry], cai->labels[c_entry], 16);
-	 aai->labels[a_entry][15]='\0';
+         strncpy(aai->labels[a_entry], cai->labels[c_entry], 16);
+         aai->labels[a_entry][15]='\0';
       } else {
-	 if (a_entry>=0) {
-	    aai->labels[a_entry][0]='\0';
-	 }
+         if (a_entry>=0) {
+            aai->labels[a_entry][0]='\0';
+         }
       }
    }
 
@@ -522,8 +513,9 @@ int copy_contact_ai_to_address_ai(const struct ContactAppInfo *cai, struct Addre
       aai->labelRenamed[i]=0;
    }
 
-   return 0;
+   return EXIT_SUCCESS;
 }
+*/
 
 int copy_contact_to_address(const struct Contact *c, struct Address *a)
 {
@@ -535,9 +527,9 @@ int copy_contact_to_address(const struct Contact *c, struct Address *a)
       
       a->entry[a_entry]=NULL;
       if ((c_entry>=0) && (a_entry>=0)) {
-	 if (c->entry[c_entry]) {
-	    a->entry[a_entry]=strdup(c->entry[c_entry]);
-	 }
+         if (c->entry[c_entry]) {
+            a->entry[a_entry]=strdup(c->entry[c_entry]);
+         }
       }
    }
 
@@ -549,13 +541,14 @@ int copy_contact_to_address(const struct Contact *c, struct Address *a)
 
    if (a->showPhone > 4) {
       for (i=0; i<5; i++) {
-	 if (a->entry[entryPhone1 + i]) {
-	    a->showPhone = i;
-	    break;
-	 }
+         if (a->entry[entryPhone1 + i]) {
+            a->showPhone = i;
+            break;
+         }
       }
    }
-   return 0;
+
+   return EXIT_SUCCESS;
 }
 
 void free_ContactList(ContactList **cl)
@@ -572,7 +565,7 @@ void free_ContactList(ContactList **cl)
 
 int get_contact_app_info(struct ContactAppInfo *ai)
 {
-   int num;
+   int num, r;
    int rec_size;
    unsigned char *buf;
    pi_buffer_t pi_buf;
@@ -582,18 +575,23 @@ int get_contact_app_info(struct ContactAppInfo *ai)
    /* Put at least one entry in there */
    strcpy(ai->category.name[0], "Unfiled");
 
-   jp_get_app_info("ContactsDB-PAdd", &buf, &rec_size);
-   //num = jp_unpack_ContactAppInfo(ai, buf, rec_size);
+   r = jp_get_app_info("ContactsDB-PAdd", &buf, &rec_size);
+   if ((r != EXIT_SUCCESS) || (rec_size<=0)) {
+      jp_logf(JP_LOG_WARN, _("%s:%d Error reading application info %s\n"), __FILE__, __LINE__, "ContactsDB-PAdd");
+      if (buf) {
+         free(buf);
+      }
+      return EXIT_FAILURE;
+   }
+
    pi_buf.data = buf;
    pi_buf.used = rec_size;
    pi_buf.allocated = rec_size;
 
    num = jp_unpack_ContactAppInfo(ai, &pi_buf);
-
    if (buf) {
       free(buf);
    }
-
    if ((num<0) || (rec_size<=0)) {
       jp_logf(JP_LOG_WARN, _("Error reading file: %s\n"), "ContactsDB-PAdd.pdb");
       return EXIT_FAILURE;
@@ -605,21 +603,21 @@ int get_contact_app_info(struct ContactAppInfo *ai)
       int i;
 
       for (i = 0; i < 49 + 3; i++)
-	if (ai->labels[i][0] != '\0') {
-	   charset_p2j(ai->labels[i], 16, char_set);
-	}
+        if (ai->labels[i][0] != '\0') {
+           charset_p2j(ai->labels[i], 16, char_set);
+        }
       for (i = 0; i < 8; i++)
-	if (ai->phoneLabels[i][0] != '\0') {
-	   charset_p2j(ai->phoneLabels[i], 16, char_set);
-	}
+        if (ai->phoneLabels[i][0] != '\0') {
+           charset_p2j(ai->phoneLabels[i], 16, char_set);
+        }
       for (i = 0; i < 3; i++)
-	if (ai->addrLabels[i][0] != '\0') {
-	   charset_p2j(ai->addrLabels[i], 16, char_set);
-	}
+        if (ai->addrLabels[i][0] != '\0') {
+           charset_p2j(ai->addrLabels[i], 16, char_set);
+        }
       for (i = 0; i < 5; i++)
-	if (ai->IMLabels[i][0] != '\0') {
-	   charset_p2j(ai->IMLabels[i], 16, char_set);
-	}
+        if (ai->IMLabels[i][0] != '\0') {
+           charset_p2j(ai->IMLabels[i], 16, char_set);
+        }
    }
 
    return EXIT_SUCCESS;
@@ -630,11 +628,11 @@ int get_contacts(ContactList **contact_list, int sort_order)
    return get_contacts2(contact_list, sort_order, 1, 1, 1, CATEGORY_ALL);
 }
 /*
- * sort_order: 0=descending,  1=ascending
- * modified, deleted and private, 0 for no, 1 for yes, 2 for use prefs
+ * sort_order: SORT_ASCENDING | SORT_DESCENDING
+ * modified, deleted, private: 0 for no, 1 for yes, 2 for use prefs
  */
 int get_contacts2(ContactList **contact_list, int sort_order,
-		  int modified, int deleted, int privates, int category)
+                  int modified, int deleted, int privates, int category)
 {
    GList *records;
    GList *temp_list;
@@ -675,22 +673,22 @@ int get_contacts2(ContactList **contact_list, int sort_order,
 
    for (temp_list = records; temp_list; temp_list = temp_list->next) {
       if (temp_list->data) {
-	 br=temp_list->data;
+         br=temp_list->data;
       } else {
-	 continue;
+         continue;
       }
       if (!br->buf) {
-	 continue;
+         continue;
       }
 
       if ( ((br->rt==DELETED_PALM_REC)  && (!keep_deleted)) ||
-	   ((br->rt==DELETED_PC_REC)    && (!keep_deleted)) ||
-	   ((br->rt==MODIFIED_PALM_REC) && (!keep_modified)) ) {
-	 continue;
+           ((br->rt==DELETED_PC_REC)    && (!keep_deleted)) ||
+           ((br->rt==MODIFIED_PALM_REC) && (!keep_modified)) ) {
+         continue;
       }
       if ((keep_priv != SHOW_PRIVATES) &&
-	  (br->attrib & dlpRecAttrSecret)) {
-	 continue;
+          (br->attrib & dlpRecAttrSecret)) {
+         continue;
       }
 
 //#ifndef PILOT_LINK_0_12
@@ -708,36 +706,37 @@ int get_contacts2(ContactList **contact_list, int sort_order,
 
 //#ifndef PILOT_LINK_0_12
       if (num <= 0) {
-	 continue;
+         continue;
       }
 //#else /* PILOT_LINK_0_12 */
 //      if (jp_unpack_Contact(&cont, RecordBuffer, contact_v1) == -1) {
-//	 pi_buffer_free(RecordBuffer);
-//	 continue;
+//       pi_buffer_free(RecordBuffer);
+//       continue;
 //      }
 //      pi_buffer_free(RecordBuffer);
 //#endif /* PILOT_LINK_0_12 */
 
       if ( ((br->attrib & 0x0F) != category) && category != CATEGORY_ALL) {
-	 continue;
+         jp_free_Contact(&cont);
+         continue;
       }
       buf = NULL;
       if (char_set != CHAR_SET_LATIN1) {
-	 for (i = 0; i < 39; i++) {
-	    if ((cont.entry[i] != NULL) && (cont.entry[i][0] != '\0')) {
+         for (i = 0; i < 39; i++) {
+            if ((cont.entry[i] != NULL) && (cont.entry[i][0] != '\0')) {
                buf = charset_p2newj(cont.entry[i], -1, char_set);
                if (buf) {
                   free(cont.entry[i]);
                   cont.entry[i] = buf;
-	       }
-	    }
-	 }
+               }
+            }
+         }
       }
 
       temp_c_list = malloc(sizeof(ContactList));
       if (!temp_c_list) {
-	 jp_logf(JP_LOG_WARN, "get_contacts2(): %s\n", _("Out of memory"));
-	 break;
+         jp_logf(JP_LOG_WARN, "get_contacts2(): %s\n", _("Out of memory"));
+         break;
       }
       memcpy(&(temp_c_list->mcont.cont), &cont, sizeof(struct Contact));
       temp_c_list->app_type = CONTACTS;
@@ -751,9 +750,6 @@ int get_contacts2(ContactList **contact_list, int sort_order,
 
    jp_free_DB_records(&records);
 
-#ifdef JPILOT_DEBUG
-   print_contact_list(contact_list);
-#endif
    contacts_sort(contact_list, sort_order);
 
    jp_logf(JP_LOG_DEBUG, "Leaving get_contacts2()\n");
@@ -762,7 +758,7 @@ int get_contacts2(ContactList **contact_list, int sort_order,
 }
 
 int pc_contact_write(struct Contact *cont, PCRecType rt, unsigned char attrib,
-		     unsigned int *unique_id)
+                     unsigned int *unique_id)
 {
    pi_buffer_t *RecordBuffer;
    int i;
@@ -772,7 +768,7 @@ int pc_contact_write(struct Contact *cont, PCRecType rt, unsigned char attrib,
    get_pref(PREF_CHAR_SET, &char_set, NULL);
    if (char_set != CHAR_SET_LATIN1) {
       for (i = 0; i < 39; i++) {
-	 if (cont->entry[i]) 
+         if (cont->entry[i]) 
             charset_j2p(cont->entry[i], strlen(cont->entry[i])+1, char_set);
       }
    }
