@@ -19,8 +19,8 @@ void SetBasicRecordObjectAttributeDefaults(PyObject *self, int (*packer)( )) {
   ((PyPiContact*)self)->packer = packer;
 }
 
-void SetSavedBrAndRTandUniqueIDandAttribs(PCRecType rt, unsigned int unique_id, 
-						 unsigned char attrib, int size, 
+void SetSavedBrAndRTandUniqueIDandAttribs(PCRecType rt, unsigned int unique_id,
+						 unsigned char attrib, int size,
 						 void *buf, PyObject *self) {
   ((PyPiContact*)self)->saved_br.size = size;
   ((PyPiContact*)self)->saved_br.attrib = attrib;
@@ -35,7 +35,7 @@ void SetSavedBrAndRTandUniqueIDandAttribs(PCRecType rt, unsigned int unique_id,
   ((PyPiContact*)self)->secret = (attrib & 0x10) ? 1 : 0;
 
   /* http://cvs.coldsync.org/cgi-bin/viewcvs.cgi/coldsync/libpdb/
-     pdb.c?rev=1.44&content-type=text/vnd.viewcvs-markup 
+     pdb.c?rev=1.44&content-type=text/vnd.viewcvs-markup
      The archived bit is only set, if deleted is set. Otherwise,
      the bit is used as part of the category */
 
@@ -45,13 +45,13 @@ void SetSavedBrAndRTandUniqueIDandAttribs(PCRecType rt, unsigned int unique_id,
   } else {
     ((PyPiContact*)self)->archived = 0;
     ((PyPiContact*)self)->category = (attrib & 0x0F);
-    
+
   }
 }
 
 char *FriendlyNameForRecordType(PCRecType rt) {
   switch(rt) {
-  case PALM_REC: 
+  case PALM_REC:
     return "normal";
   case MODIFIED_PALM_REC:
     return "modified";
@@ -80,7 +80,7 @@ PyObject *Attribute_Repr(PyObject* self) {
       return NULL;
   }
 
-  args = Py_BuildValue("iiiiiisi", 
+  args = Py_BuildValue("iiiiiisi",
 		       ((PyPiContact*)self)->deleted,
 		       ((PyPiContact*)self)->modified,
 		       ((PyPiContact*)self)->busy,
@@ -88,8 +88,8 @@ PyObject *Attribute_Repr(PyObject* self) {
 		       ((PyPiContact*)self)->archived,
 		       ((PyPiContact*)self)->category,
 		       FriendlyNameForRecordType(((PyPiContact*)self)->rt),
-		       ((PyPiContact*)self)->unique_id);  
-  
+		       ((PyPiContact*)self)->unique_id);
+
   if (args == NULL)
     return NULL;
 
@@ -101,12 +101,12 @@ PyObject *Attribute_Repr(PyObject* self) {
 
 PyObject * PyPi_Getbool(PyObject *self, void *closure) {
   void *addr = (void *)self + (size_t) closure;
-  if (*(int *)(addr)) {
+  if (*(size_t *)(addr)) {
     Py_INCREF(Py_True);
-    return Py_True;  
+    return Py_True;
   } else {
     Py_INCREF(Py_False);
-    return Py_False;  
+    return Py_False;
   }
 }
 
@@ -122,18 +122,18 @@ int PyPi_Setbool(PyObject *self, PyObject *value, void *closure) {
     PyErr_SetString(PyExc_TypeError, "Cannot delete the attribute");
     return -1;
   }
-  
+
   if (!(PyBool_Check(value) || PyInt_Check(value))) {
     PyErr_SetString(PyExc_TypeError, "The attribute value must be a boolean");
     return -1;
   }
 
   if (PyInt_Check(value) && PyInt_AsLong(value)) {
-    *(int*)addr = 1;
+    *(size_t*)addr = 1;
   } else if (PyBool_Check(value) && (value == Py_True)) {
-    *(int*)addr = 1;
+    *(size_t*)addr = 1;
   } else {
-    *(int*)addr = 0;
+    *(size_t*)addr = 0;
   }
 
   return 0;
@@ -146,20 +146,19 @@ int PyPi_SetCategory(PyObject *self, PyObject *value, void *closure) {
     PyErr_SetString(PyExc_TypeError, "Cannot delete the attribute");
     return -1;
   }
-  
+
   if (!PyInt_Check(value)) {
     PyErr_SetString(PyExc_TypeError, "The category must be an integer");
     return -1;
   }
-  
+
   category = PyInt_AsLong(value);
   if ((category >= 0) && (category <= 15)) {
-    *(int*)addr = category;
+    *(size_t*)addr = category;
   } else {
     PyErr_SetString(PyExc_ValueError, "The category value must be 0 <= x <= 15");
     return -1;
   }
-
   return 0;
 }
 
@@ -246,3 +245,110 @@ VObject *safeAddPropValuePart(VObject *o, const char *id, char *val) {
 
   return vo;
 }
+
+void PyPi_extend_keys_from_filters(PyPiBase* base, PyObject *list) {
+  if (base->filters != NULL) {
+    //printf("Have filters to use!\n");
+    if (PySequence_Check(base->filters)) {
+      //printf("And it's a sequence\n");
+      Py_ssize_t i, n;
+      for (i=0; i<PySequence_Size(base->filters); i++) {
+	//printf("Using filter %d\n", i);
+	PyObject *filter = PySequence_GetItem(base->filters, i); // new ref
+	PyObject *keys = PyObject_CallMethod(filter, "fields", NULL);
+	for (n=0; n<PySequence_Size(keys); n++) {
+	  PyObject *item = PySequence_GetItem(keys, n); // new ref
+	  PyList_Append(list, item);
+	  Py_DECREF(item);
+	}
+	Py_DECREF(keys);
+	Py_DECREF(filter);
+      }
+    }
+  }
+}
+
+PyObject *PyPi_GetItem_from_filters(PyPiBase* self, PyObject* key) {
+  PyErr_Clear();
+  if (self->filters != NULL) {
+    PyObject *filters = self->filters;
+    // disable the filters while we're calling each one, so they don't
+    // have an infinite recursion. Later, we may explore turning off just
+    // the one we're calling, to allow them to stack...
+    self->filters = NULL;
+    //printf("Have filters to use!\n");
+    if (PySequence_Check(filters)) {
+      //printf("And it's a sequence\n");
+      Py_ssize_t i, n;
+      for (i=0; i<PySequence_Size(filters); i++) {
+	int handled=0;
+	//printf("Using filter %d\n", i);
+	PyObject *filter = PySequence_GetItem(filters, i); // new ref
+	PyObject *handles_field = PyObject_CallMethod(filter, "handles_field", "O", key);
+	if (Py_True == handles_field) {
+	  PyObject *result;
+	  //printf("Using filter %d to handle field\n", i);
+	  result = PyObject_CallMethod(filter, "get_field",
+				       "(OO)", self, key);
+	  if (result == NULL) {
+	    //printf("Filter %d returned NULL :-(\n", i);
+	    Py_DECREF(handles_field);
+	    Py_DECREF(filter);
+	    self->filters = filters;
+	    return NULL; // we expect caller to use PyErr_Occurred()
+	  }
+	  //printf("Filter %d returned a value\n", i);
+	  Py_DECREF(handles_field);
+	  Py_DECREF(filter);
+	  self->filters = filters;
+	  return result;
+	}
+      }
+    }
+    self->filters = filters;
+  }
+  return NULL;
+}
+
+int PyPi_SetItem_from_filters(PyPiBase* self, PyObject* key, PyObject* value) {
+  PyErr_Clear();
+  // once this works well, we could put it into the 'basic' files
+  if (self->filters != NULL) {
+    PyObject *filters = self->filters;
+    // disable the filters while we're calling each one, so they don't
+    // have an infinite recursion. Later, we may explore turning off just
+    // the one we're calling, to allow them to stack...
+    self->filters = NULL;
+    //printf("Have filters to use!\n");
+    if (PySequence_Check(filters)) {
+      //printf("And it's a sequence\n");
+      Py_ssize_t i, n;
+      for (i=0; i<PySequence_Size(filters); i++) {
+	int handled=0;
+	//printf("Using filter %d\n", i);
+	PyObject *filter = PySequence_GetItem(filters, i); // new ref
+	PyObject *handles_field = PyObject_CallMethod(filter, "handles_field", "O", key);
+	if (Py_True == handles_field) {
+	  //printf("Using filter %d to handle field\n", i);
+	  PyObject *result = PyObject_CallMethod(filter, "set_field",
+						 "(OOO)", self, key, value);
+	  if (result == NULL) {
+	    Py_DECREF(handles_field);
+	    Py_DECREF(filter);
+	    self->filters = filters;
+	    return 2;
+	  }
+	  Py_DECREF(result);
+	  handled = 1;
+	}
+	Py_DECREF(handles_field);
+	Py_DECREF(filter);
+	if(handled) {
+	  self->filters = filters;
+	  return 1;
+	}
+      }
+    }
+  }
+  return 0;
+}
