@@ -4,7 +4,7 @@
 
 extern PyObject* PyPiContact_New();
 extern PyObject* PyPiContact_Wrap(struct Contact*, PCRecType, unsigned int, unsigned char,
-				 int, void*);
+				 int, void*, PyObject *);
 
 extern PyTypeObject ContactType;
 
