@@ -1,20 +1,19 @@
-#include <pi-datebook.h>
+#include <pi-calendar.h>
 #include "../jpilot_src/libplugin.h"
 #include "pytype_basics.h"
 
 extern PyObject* PyPiEvent_New();
-extern PyObject* PyPiEvent_Wrap(struct Appointment*, PCRecType, unsigned int, unsigned char,
-				 int, void*);
+
+extern PyObject* PyPiEvent_Wrap(CalendarEvent_t*, PCRecType, unsigned int, unsigned char,
+				 int, void*, PyObject *);
 
 extern PyTypeObject EventType;
 
 #define PyPiEvent_Check(v)          PyObject_TypeCheck(v, &EventType)
 #define PyPiEvent_CheckExact(v)     ((v)->ob_type == &EventType)
 
-PyObject *DateTimeLocalize(PyObject *pydatetime);
-
 typedef struct {
   PyObject_HEAD
   PyObject_JPTYPE
-  struct Appointment a;
+  CalendarEvent_t a;
 } PyPiEvent;
