@@ -4,7 +4,7 @@
 
 extern PyObject* PyPiTodo_New();
 extern PyObject* PyPiTodo_Wrap(struct ToDo*, PCRecType, unsigned int, unsigned char,
-			      int, void*);
+			      int, void*, PyObject *);
 
 extern PyTypeObject TodoType;
 
