@@ -16,20 +16,26 @@ sys.path.insert(0,"./")
 
 import unittest
 import basicTests
+import dependencyTests
 import bugTests
 import todoTests
 import printerTests
 import contactTests
 import eventTests
+import pluginTests
+import conduitTests
 
 def tests():
     all_tests = unittest.TestSuite()
     all_tests.addTest(basicTests.suite())
-    all_tests.addTest(bugTests.suite())        
-    all_tests.addTest(contactTests.suite())    
+    all_tests.addTest(dependencyTests.suite())
+    all_tests.addTest(bugTests.suite())
+    all_tests.addTest(contactTests.suite())
     all_tests.addTest(eventTests.suite())
-    all_tests.addTest(todoTests.suite())    
+    all_tests.addTest(todoTests.suite())
     all_tests.addTest(printerTests.suite())
+    all_tests.addTest(pluginTests.suite())
+    all_tests.addTest(conduitTests.suite())
     return all_tests
 
 if __name__ == "__main__":
