@@ -6,8 +6,8 @@ import baseclass
 class todoTest(baseclass.baseTest):
     def setUp(self):
         baseclass.baseTest.setUp(self)
-        self.book = jppy.taskList()
-        self.t = jppy.Todo()
+        self.book = self.env.taskList
+        self.t = self.book.new()
 
     def testSetTodoValues(self):
         keys = self.t.keys()
@@ -16,7 +16,7 @@ class todoTest(baseclass.baseTest):
                 self.t[key] = mx.DateTime.now()
             elif key in ("complete", "priority"):
                 self.t[key] = 1
-            elif key in ("descrption", "note"):
+            elif key in ("description", "note"):
                 self.t[key] = "String"
         for key in keys[0:5]:
             self.t[key]
